/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * xzlarfg.h
 *
 * Code generation for function 'xzlarfg'
 *
 */

#ifndef XZLARFG_H
#define XZLARFG_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern double b_xzlarfg(int n, double *alpha1, double x[3]);
extern double xzlarfg(int n, double *alpha1, emxArray_real_T *x, int ix0);

#endif

/* End of code generation (xzlarfg.h) */
